@@ -1,6 +1,6 @@
 
 /*
- * $Id: client_side.c,v 1.90.2.13 1997/07/11 00:00:14 wessels Exp $
+ * $Id: client_side.c,v 1.90.2.14 1997/08/07 20:35:22 wessels Exp $
  *
  * DEBUG: section 33    Client-side Routines
  * AUTHOR: Duane Wessels
@@ -282,6 +282,8 @@ clientRedirectDone(void *data, char *result)
 	requestUnlink(old_request);
 	icpState->request = requestLink(new_request);
 	urlCanonical(icpState->request, icpState->url);
+	safe_free(icpState->log_url);
+	icpState->log_url = xstrdup(urlCanonicalClean(new_request));
     }
     icpParseRequestHeaders(icpState);
     fd_note(fd, icpState->log_url);
